km3modules.common.StatusBar
===========================

.. currentmodule:: km3modules.common

.. autoclass:: StatusBar

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~StatusBar.__init__
      ~StatusBar.add
      ~StatusBar.configure
      ~StatusBar.expose
      ~StatusBar.finish
      ~StatusBar.get
      ~StatusBar.pre_finish
      ~StatusBar.process
      ~StatusBar.require
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~StatusBar.name
   
   